@@ -26,14 +26,14 @@ class AbortChangeOrderRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'AbortChangeOrder','serverless')
 		self.set_uri_pattern('/pop/v1/sam/changeorder/AbortChangeOrder')
 		self.set_method('PUT')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ChangeOrderId(self):
+	def get_ChangeOrderId(self): # String
 		return self.get_query_params().get('ChangeOrderId')
 
-	def set_ChangeOrderId(self,ChangeOrderId):
-		self.add_query_param('ChangeOrderId',ChangeOrderId)
\ No newline at end of file
+	def set_ChangeOrderId(self, ChangeOrderId):  # String
+		self.add_query_param('ChangeOrderId', ChangeOrderId)
