@@ -26,14 +26,14 @@ class DeleteApplicationRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DeleteApplication','serverless')
 		self.set_uri_pattern('/pop/v1/sam/app/deleteApplication')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppId(self):
+	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+	def set_AppId(self, AppId):  # String
+		self.add_query_param('AppId', AppId)
