@@ -26,20 +26,19 @@ class DescribeApplicationImageRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DescribeApplicationImage','serverless')
 		self.set_uri_pattern('/pop/v1/sam/container/describeApplicationImage')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppId(self):
+	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
-
-	def get_ImageUrl(self):
+	def set_AppId(self, AppId):  # String
+		self.add_query_param('AppId', AppId)
+	def get_ImageUrl(self): # String
 		return self.get_query_params().get('ImageUrl')
 
-	def set_ImageUrl(self,ImageUrl):
-		self.add_query_param('ImageUrl',ImageUrl)
\ No newline at end of file
+	def set_ImageUrl(self, ImageUrl):  # String
+		self.add_query_param('ImageUrl', ImageUrl)
