@@ -26,20 +26,19 @@ class DescribeNamespaceListRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'DescribeNamespaceList','serverless')
 		self.set_uri_pattern('/pop/v1/sam/namespace/describeNamespaceList')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_HybridCloudExclude(self):
+	def get_HybridCloudExclude(self): # Boolean
 		return self.get_query_params().get('HybridCloudExclude')
 
-	def set_HybridCloudExclude(self,HybridCloudExclude):
-		self.add_query_param('HybridCloudExclude',HybridCloudExclude)
-
-	def get_ContainCustom(self):
+	def set_HybridCloudExclude(self, HybridCloudExclude):  # Boolean
+		self.add_query_param('HybridCloudExclude', HybridCloudExclude)
+	def get_ContainCustom(self): # Boolean
 		return self.get_query_params().get('ContainCustom')
 
-	def set_ContainCustom(self,ContainCustom):
-		self.add_query_param('ContainCustom',ContainCustom)
\ No newline at end of file
+	def set_ContainCustom(self, ContainCustom):  # Boolean
+		self.add_query_param('ContainCustom', ContainCustom)
