@@ -26,44 +26,39 @@ class ListNamespaceChangeOrdersRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'ListNamespaceChangeOrders','serverless')
 		self.set_uri_pattern('/pop/v1/sam/changeorder/listNamespaceChangeOrders')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_CoType(self):
+	def get_CoType(self): # String
 		return self.get_query_params().get('CoType')
 
-	def set_CoType(self,CoType):
-		self.add_query_param('CoType',CoType)
-
-	def get_NamespaceId(self):
+	def set_CoType(self, CoType):  # String
+		self.add_query_param('CoType', CoType)
+	def get_NamespaceId(self): # String
 		return self.get_query_params().get('NamespaceId')
 
-	def set_NamespaceId(self,NamespaceId):
-		self.add_query_param('NamespaceId',NamespaceId)
-
-	def get_PageSize(self):
+	def set_NamespaceId(self, NamespaceId):  # String
+		self.add_query_param('NamespaceId', NamespaceId)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_CurrentPage(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_CoStatus(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_CoStatus(self): # String
 		return self.get_query_params().get('CoStatus')
 
-	def set_CoStatus(self,CoStatus):
-		self.add_query_param('CoStatus',CoStatus)
-
-	def get_Key(self):
+	def set_CoStatus(self, CoStatus):  # String
+		self.add_query_param('CoStatus', CoStatus)
+	def get_Key(self): # String
 		return self.get_query_params().get('Key')
 
-	def set_Key(self,Key):
-		self.add_query_param('Key',Key)
\ No newline at end of file
+	def set_Key(self, Key):  # String
+		self.add_query_param('Key', Key)
