@@ -26,26 +26,24 @@ class UnbindSlbRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'UnbindSlb','serverless')
 		self.set_uri_pattern('/pop/v1/sam/app/slb')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Intranet(self):
+	def get_Intranet(self): # Boolean
 		return self.get_query_params().get('Intranet')
 
-	def set_Intranet(self,Intranet):
-		self.add_query_param('Intranet',Intranet)
-
-	def get_AppId(self):
+	def set_Intranet(self, Intranet):  # Boolean
+		self.add_query_param('Intranet', Intranet)
+	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
-
-	def get_Internet(self):
+	def set_AppId(self, AppId):  # String
+		self.add_query_param('AppId', AppId)
+	def get_Internet(self): # Boolean
 		return self.get_query_params().get('Internet')
 
-	def set_Internet(self,Internet):
-		self.add_query_param('Internet',Internet)
\ No newline at end of file
+	def set_Internet(self, Internet):  # Boolean
+		self.add_query_param('Internet', Internet)
