@@ -26,32 +26,29 @@ class UntagResourcesRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'UntagResources','serverless')
 		self.set_uri_pattern('/tags')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TagKeys(self):
+	def get_TagKeys(self): # String
 		return self.get_query_params().get('TagKeys')
 
-	def set_TagKeys(self,TagKeys):
-		self.add_query_param('TagKeys',TagKeys)
-
-	def get_DeleteAll(self):
+	def set_TagKeys(self, TagKeys):  # String
+		self.add_query_param('TagKeys', TagKeys)
+	def get_DeleteAll(self): # Boolean
 		return self.get_query_params().get('DeleteAll')
 
-	def set_DeleteAll(self,DeleteAll):
-		self.add_query_param('DeleteAll',DeleteAll)
-
-	def get_ResourceType(self):
+	def set_DeleteAll(self, DeleteAll):  # Boolean
+		self.add_query_param('DeleteAll', DeleteAll)
+	def get_ResourceType(self): # String
 		return self.get_query_params().get('ResourceType')
 
-	def set_ResourceType(self,ResourceType):
-		self.add_query_param('ResourceType',ResourceType)
-
-	def get_ResourceIds(self):
+	def set_ResourceType(self, ResourceType):  # String
+		self.add_query_param('ResourceType', ResourceType)
+	def get_ResourceIds(self): # String
 		return self.get_query_params().get('ResourceIds')
 
-	def set_ResourceIds(self,ResourceIds):
-		self.add_query_param('ResourceIds',ResourceIds)
\ No newline at end of file
+	def set_ResourceIds(self, ResourceIds):  # String
+		self.add_query_param('ResourceIds', ResourceIds)
